@@ -2,9 +2,9 @@ package Egg::Helper::E::Create;
 use strict;
 #
 # Copyright 2007 Bee Flag, Corp. All Rights Reserved.
-# Masatoshi Mizuno E<lt>mizunoE<64>bomcity.comE<gt>
+# Masatoshi Mizuno E<lt>lusheE<64>cpan.orgE<gt>
 #
-# $Id: Create.pm 236 2007-02-24 10:26:28Z lushe $
+# $Id: Create.pm 245 2007-02-24 18:21:27Z lushe $
 #
 use strict;
 use warnings;
@@ -126,7 +126,7 @@ L<Egg::Release>,
 
 =head1 AUTHOR
 
-Masatoshi Mizuno, E<lt>mizunoE<64>bomcity.comE<gt>
+Masatoshi Mizuno, E<lt>lusheE<64>cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
